# ntqr.r2 package

## Submodules

## ntqr.r2.datasketches module

```{eval-rst}
.. automodule:: ntqr.r2.datasketches
   :members:
   :undoc-members:
   :show-inheritance:
```

## ntqr.r2.evaluators module

```{eval-rst}
.. automodule:: ntqr.r2.evaluators
   :members:
   :undoc-members:
   :show-inheritance:
```

## ntqr.r2.examples module

```{eval-rst}
.. automodule:: ntqr.r2.examples
   :members:
   :undoc-members:
   :show-inheritance:
```

## Module contents

```{eval-rst}
.. automodule:: ntqr.r2
   :members:
   :undoc-members:
   :show-inheritance:
```
